@@ -11,7 +11,6 @@ from archipelagos.common.data.timeseries import TimeSeriesMetadataRequest, TimeS
 
 import io
 import pandas as pd
-import geopandas as gpd
 import numpy as np
 from urllib.parse import urlparse, urlencode, parse_qsl, urlunparse
 import requests
@@ -646,7 +645,7 @@ class Archipelagos:
             raise ValueError('response is of an unsupported type')
 
     @staticmethod
-    def _get_geopandas_data_frame(response: Any) -> gpd.GeoDataFrame:
+    def _get_geopandas_data_frame(response: Any):
         """
         Builds a GeoPandas Data Frame from a response.
 
@@ -660,6 +659,7 @@ class Archipelagos:
             if response.error_occurred:
                 raise PlatformError(response.error_code, response.error_message)
             else:
+                import geopandas as gpd
                 file_name = response.metadata.name.lower()
 
                 if file_name.endswith(".json") or file_name.endswith(".geojson"):
@@ -815,7 +815,7 @@ class Archipelagos:
                  fs_id: str,
                  name: str,
                  returns: str = "pandas",
-                 api_key: str = None) -> pd.DataFrame or np.ndarray or gpd.GeoDataFrame:
+                 api_key: str = None):
         """
         Retrieve collection data and (where possible) return it as a specified Python object types; Pandas Data Frames
         and Numpy arrays are currently supported.
